@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-from datetime import datetime, timedelta
+from datetime import datetime
 from email.mime.multipart import MIMEMultipart
 from email.mime.base import MIMEBase
 from email.mime.text import MIMEText
@@ -11,7 +11,6 @@ from multiprocessing import Pool
 from .. import core
 from ..consts import CONFIG
 from ..consts import RAPPORT_HTML
-from ..consts import REDIS_DB
 from ..customer import Customer
 from ..product import Product
 from ..product_gp import Product_GP
@@ -267,93 +266,142 @@ def apply(for_real, send_mail, random):
 
 
 @cmd.command()
-@click.option('--start')
-@click.option('--stop')
-@click.option('--send-mail')
-def details(start, stop, send_mail):
-    """Renvoie le détail de consommation des clients"""
-    if not stop:
-        stop = datetime.now() - timedelta(1)
-    if not start:
-        start = datetime.now() - timedelta(30)
+@click.argument('client_name')
+def details(client_name):
+    """Renvoie le détail de consommation des 30 derniers jours du client"""
+
+    def str_data(conso_bytes):
+        conso_megabytes = round(
+            (float(conso_bytes) / 1000000),
+            2
+            )
+        result = str(conso_megabytes).replace('.', ',')
+        if result == '0,0':
+            return '0'
+        else:
+            return result
+
+    client = Customer(client_name)
+    cdrs = client.get_cdr_summary(daily_details=True)
+    consumption = cdrs['consumption']
+    details = consumption['details']
     dataset = tablib.Dataset()
-    dataset.headers = ['client', 'produit', 'politique_fup', 'total']
-    date = start
-    while date <= stop:
-        dataset.headers.append(date.strftime('%d%m%Y'))
-        date += timedelta(1)
-    customers = Customer.all()
-    cdrs = {}
-    with click.progressbar(customers) as _customers:
-        for customer in _customers:
-            key = 'cdr_start_date:{}'.format(customer.name)
-            _start = REDIS_DB.get(key)  # s'il n'y a pas de clés ce sera None
-            if _start:
-                _start = _start.decode('utf-8')
-                start = datetime.strptime(
-                    _start + ' 00:00:00', '%d%m%Y %H:%M:%S'
-                    )
-            msg = '> Conso de {} du {} au {}'.format(
-                customer.name,
-                start.strftime('%d/%m/%Y'),
-                stop.strftime('%d/%m/%Y')
-                )
-            click.echo(msg)
-            cdrs[customer.name] = {
-                'product': customer.product.name,
-                'cdrs': customer.filter_cdrs_policy_wise(
-                    customer.get_cdr(start=start, stop=stop)
-                    )
+    dataset.headers = [
+        'date',
+        'HO',
+        'data_limit',
+        'total_download_national_HO',
+        'total_upload_national_HO',
+        'total_download_HO',
+        'total_upload_HO',
+        'total_HO',
+        'total_download_national_HNO',
+        'total_upload_national_HNO',
+        'total_download_HNO',
+        'total_upload_HNO',
+        'total_HNO'
+       ]
+    for daily_detail in details:
+        click.echo(daily_detail)
+        click.echo('\n')
+        date = daily_detail['date']
+        daily_total_download = daily_detail['octets_in']
+        daily_total_upload = daily_detail['octets_out']
+        daily_total = daily_detail['total']
+        daily_cdr_by_source = daily_detail['details']
+        daily_cdr_by_source = {
+            i['source']: {
+                'octets_in': i['octets_in'],
+                'octets_out': i['octets_out'],
+                'total': i['total']
                 }
-    for customer, infos in cdrs.items():
-        product = infos['product']
-        data = infos['cdrs']
-        for policy_cdrs in data:
-            policy_name = policy_cdrs['name']
-            total = round(
-                policy_cdrs['total']/1000000000, 2
+            for i in daily_cdr_by_source
+            }
+        daily_total_download_national = daily_cdr_by_source.get(
+            'national', {}).get(
+                'octets_in', 0
                 )
-            line = [customer, product, policy_name, total]
-            for date in dataset.headers[4:]:
-                for cdr in policy_cdrs['details']:
-                    if cdr['date'] == date:
-                        line.append(
-                            round(
-                                cdr['total']/1000000000, 2
-                                )
-                            )
-                        break
-                else:
-                    line.append(0)
-            dataset.rpush(line)
-    with open('/tmp/conso.csv', 'w') as f:
-        f.write(dataset.export('csv'))
-    if send_mail:
-        message = "Consommation des clients du {} au {}".format(
-            start.strftime('%d%m%Y'),
-            stop.strftime('%d%m%Y')
-            )
-        content = MIMEText(message, 'plain', 'utf-8')
-        attachment = MIMEBase('text', 'csv')
-        fp = open('/tmp/conso.csv', 'rb')
-        attachment.set_payload(fp.read())
-        fp.close()
-        attachment.add_header(
-            'Content-Disposition',
-            'attachment',
-            filename='conso.csv'
-            )
-        msg = MIMEMultipart()
-        msg['Subject'] = "Détails de consommation FUP"
-        msg['From'] = CONFIG['ALERT']['from']
-        msg['To'] = send_mail
-        msg.attach(attachment)
-        msg.attach(content)
-        s = smtplib.SMTP('localhost')
-        s.sendmail(
-            CONFIG['ALERT']['from'],
-            send_mail.replace(' ', '').split(','),
-            msg.as_string()
-            )
-        s.quit()
+        daily_total_upload_national = daily_cdr_by_source.get(
+            'national', {}).get(
+                'octets_out', 0
+                )
+        daily_cdrs_policy_wise = daily_detail['policy_wise']
+        for info in daily_cdrs_policy_wise:
+            policy = info['interval']
+            data_limit = info['data_limit']
+            info_by_source = {
+                i['source']: {
+                    'octets_in': i['octets_in'],
+                    'octets_out': i['octets_out'],
+                    'total': i['total']
+                    }
+                for i in info['details']
+                }
+            daily_total_download_for_fup_HO = info['octets_in']
+            daily_total_upload_for_fup_HO = info['octets_out']
+            daily_total_download_national_HO = info_by_source.get(
+                'national', {}).get(
+                    'octets_in', 0
+                    )
+            daily_total_upload_national_HO = info_by_source.get(
+                'national', {}).get(
+                    'octets_out', 0
+                    )
+            daily_total_download_HO = (
+                daily_total_download_for_fup_HO +
+                daily_total_download_national_HO
+                )
+            daily_total_upload_HO = (
+                daily_total_upload_for_fup_HO +
+                daily_total_upload_national_HO
+                )
+            daily_total_HO = (
+                daily_total_download_HO +
+                daily_total_upload_HO
+                )
+            assert(daily_total_download >= daily_total_download_HO)
+            daily_total_download_HNO = (
+                daily_total_download - daily_total_download_HO
+                )
+            assert(daily_total_upload >= daily_total_upload_HO)
+            daily_total_upload_HNO = (
+                daily_total_upload - daily_total_upload_HO
+                )
+            assert(
+                daily_total_download_national >=
+                daily_total_download_national_HO
+                )
+            daily_total_download_national_HNO = (
+                daily_total_download_national -
+                daily_total_download_national_HO
+                )
+            assert(
+                daily_total_upload_national >=
+                daily_total_upload_national_HO
+                )
+            daily_total_upload_national_HNO = (
+                daily_total_upload_national -
+                daily_total_upload_national_HO
+                )
+            daily_total_HNO = daily_total - daily_total_HO
+            dataset.rpush(
+                [
+                    '{}/{}/{}'.format(date[:2], date[2:4], date[4:]),
+                    policy,
+                    data_limit * 1000,
+                    str_data(daily_total_download_national_HO),
+                    str_data(daily_total_upload_national_HO),
+                    str_data(daily_total_download_HO),
+                    str_data(daily_total_upload_HO),
+                    str_data(daily_total_HO),
+                    str_data(daily_total_download_national_HNO),
+                    str_data(daily_total_upload_national_HNO),
+                    str_data(daily_total_download_HNO),
+                    str_data(daily_total_upload_HNO),
+                    str_data(daily_total_HNO)
+                    ]
+                )
+    with open('/tmp/details_{}.csv'.format(client_name), 'w') as f:
+        content = dataset.export('csv', delimiter=';')
+        f.write(content)
 # EOF
