@@ -8,6 +8,8 @@ from blueflask.lib.errors import unauthorized
 
 from ...consts import SERVICE_CODE
 
+import traceback
+
 
 api = Blueprint('api', __name__, url_prefix='/api/v1')
 __version__ = '1.0'
@@ -47,14 +49,16 @@ def method_not_allowed_error(e):
 
 @api.errorhandler(500)
 def internal_server_error(e):
-    msg = 'Please contact API maintainers'
+    message = {
+        'error': str(e),
+        'traceback': ''.join(traceback.format_tb(e.__traceback__))
+        }
     return internal_error(
-        msg,
+        message,
         service_code=SERVICE_CODE,
         request_id=request.headers.get('X-Request-Id')
         )
 
-
 from . import customers  # NOQA
 
 # EOF
