@@ -20,32 +20,29 @@ def get_customers():
     ---
     tags:
       - Customers
-    components:
-      securitySchemes:
-        basicAuth:
-          type: http
-          scheme: basic
-    security:
-      - basicAuth: []
-    responses:
-      200:
-        description: La liste des clients
-        schema:
-          id: Liste de clients
+    definitions:
+      - schema:
+          id: Informations
+          properties:
+            name:
+              description: Nom d'utilisateur du client
+              type: string
+            refnum:
+              description: Identifiant unique du client
+              type: string
+      - schema:
+          id: Customers
           properties:
             length:
               type: integer
-              description: Nombre total de clients trouvés
+              description: Nombre de clients
             customers:
               type: array
-              items:
-                properties:
-                  name:
-                    description: Nom d'utilisateur du client
-                    type: string
-                  refnum:
-                    description: Identifiant unique du client
-                    type: string
+              $ref: "#/definitions/Informations"
+    responses:
+      200:
+        description: La liste des clients
+        $ref: "#/definitions/Informations
       204:
         description: Aucun client n'a été trouvé
       500:
@@ -75,6 +72,30 @@ def get_customer(uuid):
     ---
     tags:
       - Customers
+    definitions:
+      - schema:
+        id: Customer Details
+        properties:
+          name:
+            description: Nom d'utilisateur du client
+            type: string
+          refnum:
+            description: Identifiant unique du client
+            type: string
+          product:
+            description: Nom du produit du client
+            type: string
+          fup_status:
+            description: Etat du client par politique
+            type: array
+            items:
+              properties:
+                status:
+                  type: string
+                  description: Etat du client
+                interval:
+                  type: string
+                  description: Interval horaire d'application de la politique
     components:
       securitySchemes:
         basicAuth:
@@ -85,29 +106,6 @@ def get_customer(uuid):
     responses:
       200:
         description: Les informations du client
-        schema:
-          id: Informations du client
-          properties:
-            name:
-              description: Nom d'utilisateur du client
-              type: string
-            refnum:
-              description: Identifiant unique du client
-              type: string
-            product:
-              description: Nom du produit du client
-              type: string
-            fup_status:
-              description: Etat du client par politique
-              type: array
-              items:
-                properties:
-                  status:
-                    type: string
-                    description: Etat du client
-                  interval:
-                    type: string
-                    description: Interval horaire d'application de la politique
       404:
         description: Aucun client n'a été trouvé
       500:
@@ -151,13 +149,6 @@ def get_customer_consumption(uuid):
     ---
     tags:
       - Customers
-    components:
-      securitySchemes:
-        basicAuth:
-          type: http
-          scheme: basic
-    security:
-      - basicAuth: []
     responses:
       200:
         description: La consommation détaillée
@@ -209,56 +200,48 @@ def get_customer_consumption(uuid):
         description: Erreur interne
     """
     try:
-        int(uuid)
-    except ValueError:
         customer = lib_customer.Customer(uuid)
+    except ValueError:
+        return not_found(
+            message="Le client {} n'existe pas".format(uuid),
+            code='{}-{}'.format(
+                SERVICE_CODE,
+                '4040'
+                ),
+            service_code=SERVICE_CODE
+            )
     else:
-        search_customer = [
-            customer for customer in lib_customer.Customer.all()
-            if customer.refnum == uuid
-            ]
-        if search_customer:
-            customer = search_customer.pop()
-        else:  # aucun client n'a été trouvé
-            return not_found(
-                message="Le client {} n'existe pas".format(uuid),
-                code='{}-{}'.format(
-                    SERVICE_CODE,
-                    '4040'
-                    ),
-                service_code=SERVICE_CODE
-                )
-    start = request.args.get('start', None)
-    stop = request.args.get('stop', None)
-    if not start:
-        start = datetime.now() - timedelta(30)
-    else:
-        try:
-            start = datetime.strptime(start, '%d%m%Y')
-        except ValueError:
-            return bad_request(
-                message='Le format de date est ddmmyyyy',
-                code='{}-{}'.format(
-                    SERVICE_CODE,
-                    '4001'
-                    ),
-                service_code=SERVICE_CODE
-                )
-    if not stop:
-        stop = datetime.now() - timedelta(1)
-    else:
-        try:
-            stop = datetime.strptime(stop, '%d%m%Y')
-        except ValueError:
-            return bad_request(
-                message='Le format correct de date est ddmmyyyy',
-                code='{}-{}'.format(
-                    SERVICE_CODE,
-                    '4001'
-                    ),
-                service_code=SERVICE_CODE
-                )
-    infos = customer.get_cdr_summary(start.date(), stop.date())
-    return jsonify(infos)
+        start = request.args.get('start', None)
+        stop = request.args.get('stop', None)
+        if not start:
+            start = datetime.now() - timedelta(30)
+        else:
+            try:
+                start = datetime.strptime(start, '%d%m%Y')
+            except ValueError:
+                return bad_request(
+                    message='Le format de date est ddmmyyyy',
+                    code='{}-{}'.format(
+                        SERVICE_CODE,
+                        '4001'
+                        ),
+                    service_code=SERVICE_CODE
+                    )
+        if not stop:
+            stop = datetime.now() - timedelta(1)
+        else:
+            try:
+                stop = datetime.strptime(stop, '%d%m%Y')
+            except ValueError:
+                return bad_request(
+                    message='Le format correct de date est ddmmyyyy',
+                    code='{}-{}'.format(
+                        SERVICE_CODE,
+                        '4001'
+                        ),
+                    service_code=SERVICE_CODE
+                    )
+        infos = customer.get_cdr_summary(start.date(), stop.date())
+        return jsonify(infos)
 
 # EOF
