@@ -68,6 +68,52 @@ class Customer(object):
                     )
         return result
 
+    def set_refnum(self, refnum):
+        """Changement du refnum"""
+        url = core.database_url(**FUPDB_CREDENTIALS)
+        with records.Database(url) as db:
+            sql = (
+                "UPDATE customer SET refnum=:refnum "
+                "WHERE name=:name"
+                )
+            db.query(
+                sql,
+                refnum=refnum,
+                name=self.name
+                )
+        log_msg = (
+            "Changement de refnum de {}: {} => {}"
+            ).format(
+                self.name,
+                self.refnum,
+                refnum
+                )
+        LOGS.logger.info(log_msg)
+        self.refnum = refnum
+
+    def set_product(self, product_name):
+        """Changement du produit"""
+        url = core.database_url(**FUPDB_CREDENTIALS)
+        with records.Database(url) as db:
+            sql = (
+                "UPDATE customer SET product=:product "
+                "WHERE name=:name"
+                )
+            db.query(
+                sql,
+                product=product_name,
+                name=self.name
+                )
+        log_msg = (
+            "Changement de produit de {}: {} => {}"
+            ).format(
+                self.name,
+                self.product.name,
+                product_name
+                )
+        LOGS.logger.info(log_msg)
+        self.product = product.Product(product_name)
+
     def get_cdr_from_aiguillier(self):
         """Récupération des CDRs des 30 derniers jours
         depuis l'API d'Aiguillier pour les clients business"""
@@ -81,7 +127,14 @@ class Customer(object):
             params={'customer': self.name}
             )
         infos = response['content']
-        if 'refnum' not in infos:  # le client n'existe plus
+        nill_condition = (
+            'refnum' not in infos or
+            infos['product'] not in [i.name for i in product.Product.all()]
+            )
+        if nill_condition:
+            # le client n'existe plus
+            # ou son produit a changé et il n'est plus concerné
+            # par le fup
             customer_status = self.fup_status
             for policy_name in self.product.policies:
                 status = customer_status.get(policy_name)
@@ -109,6 +162,7 @@ class Customer(object):
                 db.query(sql, name=self.name)
                 sql = "DELETE FROM fup WHERE customer=:name"
                 db.query(sql, name=self.name)
+            LOGS.logger.info("Suppression du client {}".format(self.name))
             return None
         else:
             cdrs = sorted(
@@ -129,7 +183,8 @@ class Customer(object):
             params = []
             for date, infos in cdrs:
                 LOGS.logger.info(
-                    "{} obtenu depuis Aiguillier".format(
+                    "{} {} obtenu depuis Aiguillier".format(
+                        self.name,
                         date.strftime('%d%m%Y')
                         )
                     )
@@ -142,6 +197,7 @@ class Customer(object):
                     params.append(
                         {
                             'name': self.name,
+                            'product': self.product.name,
                             'date_time': date_time,
                             'source': info['source'],
                             'octetsin': info.get('octetsin', 0),
@@ -172,9 +228,11 @@ class Customer(object):
                 with records.Database(url) as db:
                     sql = (
                         "INSERT INTO cdr "
-                        "(customer, datetime, source, octets_in, octets_out) "
+                        "(customer, datetime, source, "
+                        "octets_in, octets_out, product) "
                         "VALUES "
-                        "(:name, :date_time, :source, :octetsin, :octetsout)"
+                        "(:name, :date_time, :source, "
+                        ":octetsin, :octetsout, :product)"
                         )
                     db.bulk_query(sql, *params)
             return result
@@ -304,13 +362,17 @@ class Customer(object):
                     source_day_octets_out = sum(
                         [i['octets_out'] for i in element]
                         )
+                    source_day_total = (
+                        source_day_octets_in + source_day_octets_out
+                        )
                     sources[source]['octets_in'] += source_day_octets_in
                     sources[source]['octets_out'] += source_day_octets_out
                     day_details.append(
                         {
                             'source': source,
                             'octets_in': source_day_octets_in,
-                            'octets_out': source_day_octets_out
+                            'octets_out': source_day_octets_out,
+                            'total': source_day_total
                             }
                         )
                 info['total'] += day_total
@@ -426,7 +488,11 @@ class Customer(object):
                         )
         return cdrs_by_policies
 
-    def get_cdr_summary(self, start=None, stop=None):
+    def get_cdr_summary(self, start=None, stop=None, daily_details=False):
+        if not start:
+            start = (datetime.now() - timedelta(30))
+        if not stop:
+            stop = (datetime.now() - timedelta(1))
         cdrs = self.get_cdr(start, stop)
         sorted_cdrs = sorted(
             cdrs,
@@ -443,19 +509,46 @@ class Customer(object):
                 }
             }
         for date in sorted_cdrs:
-            data = cdrs[date]
-            octets_in = sum([i['octets_in'] for i in data])
-            octets_out = sum([i['octets_out'] for i in data])
+            daily_data = cdrs[date]
+            daily_data = sorted(daily_data, key=lambda x: x['source'])
+            daily_octets_in = sum([i['octets_in'] for i in daily_data])
+            daily_octets_out = sum([i['octets_out'] for i in daily_data])
+            daily_total = daily_octets_in + daily_octets_out
+            daily_data_by_source = groupby(
+                sorted(daily_data, key=lambda x: x['source']),
+                key=lambda x: x['source']
+                )
+            total_by_source = []
+            for source, foo in daily_data_by_source:
+                foo = list(foo)
+                octets_in = sum([i['octets_in'] for i in foo])
+                octets_out = sum([i['octets_out'] for i in foo])
+                total_by_source.append(
+                    {
+                        'source': source,
+                        'octets_in': octets_in,
+                        'octets_out': octets_out,
+                        'total': octets_in + octets_out
+                        }
+                    )
             info = {
                 'date': date,
-                'total': octets_in + octets_out,
-                'octets_in': octets_in,
-                'octets_out': octets_out,
+                'total': daily_total,
+                'octets_in': daily_octets_in,
+                'octets_out': daily_octets_out,
+                'details': total_by_source,
                 'policy_wise': []
                 }
-            cdrs_by_policies = self.filter_cdrs_policy_wise({date: data})
+            cdrs_by_policies = self.filter_cdrs_policy_wise({date: daily_data})
             for i in cdrs_by_policies:
+                # comme c'est sur une seule journée
+                #  - i['details'] est de longueur 1
+                #  - i['sources'] et i['details'][0]['details'] sont pareils
+                details = i['details'][0]['details']
                 del i['details']
+                del i['sources']
+                if daily_details:
+                    i['details'] = details
                 info['policy_wise'].append(i)
             infos['consumption']['details'].append(info)
             infos['consumption']['length'] += 1
